import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * A soundboard that plays a sound when clicked on or activated in some other way.
 * 
 * @author Michael Berry (mjrb4)
 */
public abstract class SoundBoard  extends Actor
{

    /** The value the resistance needs to be below to activate the sound. */
    public static final int TOLERANCE = 100;
    private GreenfootSound sound;
    private Color color;
    private long lastTime = -1;
    private long timeDelay = 100;
    private GreenfootImage image;
    private static GreenfootImage whiteImage;
    
    /**
     * Create a new soundboard.
     */
    public SoundBoard(GreenfootSound sound, Color color) {
        this.sound = sound;
        this.color = color;
    }
    
    /**
     * Play the sound that goes with this board.
     */
    public void playSound() {
        long curTime = System.currentTimeMillis();
        if(lastTime==-1 || curTime-lastTime>timeDelay) {
            if(sound.isPlaying()) {
                sound.stop();
            }
            sound.play();
            lastTime = curTime;
        }
    }
    
    public void addedToWorld(World world) {
        whiteImage = new GreenfootImage(50,50);
        whiteImage.setColor(Color.WHITE);
        whiteImage.fillRect(0,0,50,50);
        image = new GreenfootImage(50,50);
        image.setColor(color);
        image.fillRect(0,0,50,50);
        setImage(image);
    }
    
    public void act() {
        if(Greenfoot.mouseClicked(this)) {
            playSound();
        }
        if(sound.isPlaying()) {
            setImage(whiteImage);
        }
        else {
            setImage(image);
        }
    }
    
}
